#[non_exhaustive]pub enum VerifyErrorKind {
CheckpointSummary {
source: Box<dyn Error + Send + Sync + 'static>,
},
MissingTarget,
TransactionTargetMismatch,
TransactionDigestMismatch,
TransactionNotInCheckpoint,
TransactionSignaturesMismatch,
EventsDigestMismatch,
MissingEvents,
EventTransactionMismatch,
EventSequenceOutOfBounds {
sequence: u64,
},
ObjectNotFound,
}Expand description
The cause of a VerifyError.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CheckpointSummary
The committee signature or checkpoint-contents commitment is invalid.
MissingTarget
The proof does not declare a transaction, object, or event target.
TransactionTargetMismatch
The selected transaction differs from the transaction packaged in the proof.
TransactionDigestMismatch
The packaged transaction does not match the transaction digest in its effects.
TransactionNotInCheckpoint
The packaged transaction effects are absent from the authenticated checkpoint contents.
TransactionSignaturesMismatch
The packaged user signatures differ from those committed by the checkpoint.
EventsDigestMismatch
The presence or digest of packaged events does not match the transaction effects.
MissingEvents
Event targets are present but the proof does not contain transaction events.
EventTransactionMismatch
An event target identifies a transaction other than the one proven by the envelope.
EventSequenceOutOfBounds
An event target refers to an index outside the packaged transaction events.
ObjectNotFound
A claimed object reference is absent from the packaged transaction effects.