pub struct ProofV1 {
pub chain: ChainIdentifier,
pub targets: ProofTargets,
pub checkpoint_summary: CertifiedCheckpointSummary,
pub checkpoint_contents: CheckpointContents,
pub transaction_proof: TransactionProof,
}Expand description
Version 1 evidence that a transaction is included in a certified checkpoint.
ProofTargets records the values selected by the caller. The checkpoint
and transaction proof fields contain the evidence for those targets.
Proof::chain identifies the network reported by the proof source. It is
informational and is not checked during verification.
Fields
chain: ChainIdentifierThe network reported by the proof source.
targets: ProofTargetsThe values selected for this proof.
checkpoint_summary: CertifiedCheckpointSummaryThe certified summary of the checkpoint containing the transaction.
checkpoint_contents: CheckpointContentsContents committed to by the checkpoint summary.
transaction_proof: TransactionProofThe transaction and its execution data
Implementations
Sourceimpl ProofV1
impl ProofV1
Sourcepub fn new(
chain: ChainIdentifier,
targets: ProofTargets,
checkpoint_summary: CertifiedCheckpointSummary,
checkpoint_contents: CheckpointContents,
transaction_proof: TransactionProof,
) -> Self
pub fn new( chain: ChainIdentifier, targets: ProofTargets, checkpoint_summary: CertifiedCheckpointSummary, checkpoint_contents: CheckpointContents, transaction_proof: TransactionProof, ) -> Self
Creates a version 1 proof payload.